@@ -8,5 +8,5 @@ MAX_MIRROR_LISTING_CHUNK_SIZE = 5
 MAX_MIRROR_WRITE_CHUNK_SIZE = 8192
 MAX_REMOTE_RECURSION_DEPTH = 8
 
-IS_DEVELOPMENT = environ.get('DEBUG', False)
+IS_DEVELOPMENT = bool(int(environ.get('DEBUG', '0')))
 
